const express = require("express");
const router = express.Router();
const auth_module = require("./auth_modules");
const common = require("../../../../config/common");
const { t } = require("localizify");
const middleware = require("../../../../middleware/validation");

// * for signup step 1
router.post("/sign-up", (req, res) => {
    const rules = {
        first_name: "required",
        last_name: "required",
        email: "required|email",
        country_code: "required",
        mobile_number: "required",
        password: "required",
        device_type: "required|in:A,I",
        device_token: "required",
        os_version: "required",
        device_name: "required",
        model_name: "required",
        ip: "required",
        uuid: "required",
        location: "required",
        latitude: "required",
        longitude: "required",
    };

    const message = { required: t("required"), email: t("valid") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.signUpVerification(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For Sending OTP to user OR Updating OTP or Resending OTP
router.post("/request-otp", (req, res) => {
    const rules = {
        country_code: "required",
        mobile_number: "required|numeric",
    };

    const message = { required: t("required"), digits: t("valid") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.requestOtp(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For OTP Verification
router.post("/otp-verification", (req, res) => {
    const rules = {
        country_code: "required",
        mobile_number: "required|numeric",
        otp: "required|digits:4",
    };

    const message = { required: t("required"), digits: t("valid") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.otpVerification(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For checking the mobile number when user forgots password
router.post("/forgot-password-mobile-verification", (req, res) => {
    const rules = {
        country_code: "required",
        mobile_number: "required|numeric",
    };

    const message = { required: t("required"), digits: t("valid"), numeric: t("valid") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.mobileVerification(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For changing the forgotten password
router.post("/change-forgot-password", (req, res) => {
    const rules = {
        new_password: "required",
    };

    const message = { required: t("required") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.changeForgotPassword(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For changing the password
router.post("/change-password", (req, res) => {
    const rules = {
        old_password: "required",
        new_password: "required",
    };

    const message = { required: t("required") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.changePassword(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * For login through mobile number , country code and password
router.post("/login", function (req, res) {
    const rules = {
        mobile_number: "required|numeric",
        password: "required",
        country_code: "required",
        device_type: "required|in:A,I",
        device_token: "required",
        os_version: "required",
        device_name: "required",
        model_name: "required",
        ip: "required",
        uuid: "required",
    };
    const message = { required: req.language.required, numerid: t("valid") };

    if (middleware.checkValidationRules(req.body, res, rules, message)) {
        auth_module.login(req.body, function (code, message, data) {
            common.send_response(req.body, res, code, message, data);
        });
    }
});

// * To edit the profile of the particular customer
router.post("/edit-customer-data", function (req, res) {
    auth_module.editCustomerData(req.body, function (code, message, data) {
        common.send_response(req.body, res, code, message, data);
    });
});

// * To get data of the particular customer
router.get("/customer-data", function (req, res) {
    auth_module.customerData(req.body, function (code, message, data) {
        common.send_response(req.body, res, code, message, data);
    });
});

// * To delete customer account
router.post("/delete-account", function (req, res) {
    auth_module.deleteAccount(req.body, function (code, message, data) {
        common.send_response(req.body, res, code, message, data);
    });
});

// * For logout
router.post("/logout", function (req, res) {
    auth_module.logout(req.body, function (code, message, data) {
        common.send_response(req.body, res, code, message, data);
    });
});

module.exports = router;
